@@ -2,7 +2,7 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-use crate::rules::parser::ParserError;
+use crate::rules::reference::parser::ParserError;
 use displaydoc::Display;
 use icu_provider::prelude::DataError;
 
